@@ -15,7 +15,7 @@
 """
 
 
-__version_info__ = ('0', '0', '1')
+__version_info__ = ('0', '2', '2')
 __version__ = '.'.join(__version_info__)
 __author__ = 'Stormpath, Inc.'
 __license__ = 'Apache'
@@ -118,11 +118,17 @@ class StormpathManager(object):
 
         :param obj app: The Flask app.
         """
+        app.config['REMEMBER_COOKIE_DURATION'] = app.config['STORMPATH_COOKIE_DURATION']
+        app.config['REMEMBER_COOKIE_DOMAIN'] = app.config['STORMPATH_COOKIE_DOMAIN']
+
         app.login_manager = LoginManager(app)
         app.login_manager.login_view = 'stormpath.login'
         app.login_manager.user_callback = self.load_user
         app.stormpath_manager = self
 
+        # Make this Flask session expire automatically.
+        app.config['PERMANENT_SESSION_LIFETIME'] = app.config['STORMPATH_COOKIE_DURATION']
+
     def init_routes(self, app):
         """
         Initialize our built-in routes.
